summaryrefslogtreecommitdiffstats
path: root/digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp')
-rw-r--r--digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp106
1 files changed, 53 insertions, 53 deletions
diff --git a/digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp b/digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp
index 5caf1e9..f131373 100644
--- a/digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp
+++ b/digikam/imageplugins/antivignetting/imageeffect_antivignetting.cpp
@@ -22,16 +22,16 @@
*
* ============================================================ */
-// Qt includes.
+// TQt includes.
-#include <qlabel.h>
-#include <qwhatsthis.h>
-#include <qlayout.h>
-#include <qimage.h>
-#include <qpixmap.h>
-#include <qpainter.h>
-#include <qpen.h>
-#include <qtabwidget.h>
+#include <tqlabel.h>
+#include <tqwhatsthis.h>
+#include <tqlayout.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
+#include <tqpainter.h>
+#include <tqpen.h>
+#include <tqtabwidget.h>
// KDE includes.
@@ -59,12 +59,12 @@
namespace DigikamAntiVignettingImagesPlugin
{
-ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(QWidget* parent)
- : Digikam::ImageGuideDlg(parent, i18n("Vignetting Correction"),
+ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(TQWidget* tqparent)
+ : Digikam::ImageGuideDlg(tqparent, i18n("Vignetting Correction"),
"antivignettings", false, true, false,
Digikam::ImageGuideWidget::HVGuideMode, 0, true)
{
- QString whatsThis;
+ TQString whatsThis;
KAboutData* about = new KAboutData("digikam",
I18N_NOOP("Vignetting Correction"),
@@ -85,23 +85,23 @@ ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(QWidget* parent)
// -------------------------------------------------------------
- QWidget *gboxSettings = new QWidget(plainPage());
- QGridLayout* gridSettings = new QGridLayout( gboxSettings, 13, 2, spacingHint());
-
- m_maskPreviewLabel = new QLabel( gboxSettings );
- m_maskPreviewLabel->setAlignment ( Qt::AlignHCenter | Qt::AlignVCenter );
- QWhatsThis::add( m_maskPreviewLabel, i18n("<p>You can see here a thumbnail preview of the anti-vignetting "
- "mask applied to the image.") );
- gridSettings->addMultiCellWidget(m_maskPreviewLabel, 0, 0, 0, 2);
+ TQWidget *gboxSettings = new TQWidget(plainPage());
+ TQGridLayout* gridSettings = new TQGridLayout( gboxSettings, 13, 2, spacingHint());
+
+ m_tqmaskPreviewLabel = new TQLabel( gboxSettings );
+ m_tqmaskPreviewLabel->tqsetAlignment ( TQt::AlignHCenter | TQt::AlignVCenter );
+ TQWhatsThis::add( m_tqmaskPreviewLabel, i18n("<p>You can see here a thumbnail preview of the anti-vignetting "
+ "tqmask applied to the image.") );
+ gridSettings->addMultiCellWidget(m_tqmaskPreviewLabel, 0, 0, 0, 2);
// -------------------------------------------------------------
- QLabel *label1 = new QLabel(i18n("Density:"), gboxSettings);
+ TQLabel *label1 = new TQLabel(i18n("Density:"), gboxSettings);
m_densityInput = new KDoubleNumInput(gboxSettings);
m_densityInput->setPrecision(1);
m_densityInput->setRange(1.0, 20.0, 0.1, true);
- QWhatsThis::add( m_densityInput, i18n("<p>This value controls the degree of intensity attenuation by the filter "
+ TQWhatsThis::add( m_densityInput, i18n("<p>This value controls the degree of intensity attenuation by the filter "
"at its point of maximum density."));
gridSettings->addMultiCellWidget(label1, 1, 1, 0, 2);
@@ -109,12 +109,12 @@ ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(QWidget* parent)
// -------------------------------------------------------------
- QLabel *label2 = new QLabel(i18n("Power:"), gboxSettings);
+ TQLabel *label2 = new TQLabel(i18n("Power:"), gboxSettings);
m_powerInput = new KDoubleNumInput(gboxSettings);
m_powerInput->setPrecision(1);
m_powerInput->setRange(0.1, 2.0, 0.1, true);
- QWhatsThis::add( m_powerInput, i18n("<p>This value is used as the exponent controlling the fall-off in density "
+ TQWhatsThis::add( m_powerInput, i18n("<p>This value is used as the exponent controlling the fall-off in density "
"from the center of the filter to the periphery."));
gridSettings->addMultiCellWidget(label2, 3, 3, 0, 2);
@@ -122,52 +122,52 @@ ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(QWidget* parent)
// -------------------------------------------------------------
- QLabel *label3 = new QLabel(i18n("Radius:"), gboxSettings);
+ TQLabel *label3 = new TQLabel(i18n("Radius:"), gboxSettings);
m_radiusInput = new KDoubleNumInput(gboxSettings);
m_radiusInput->setPrecision(1);
m_radiusInput->setRange(-100.0, 100.0, 0.1, true);
- QWhatsThis::add( m_radiusInput, i18n("<p>This value is the radius of the center filter. It is a multiple of the "
+ TQWhatsThis::add( m_radiusInput, i18n("<p>This value is the radius of the center filter. It is a multiple of the "
"half-diagonal measure of the image, at which the density of the filter falls "
"to zero."));
gridSettings->addMultiCellWidget(label3, 5, 5, 0, 2);
gridSettings->addMultiCellWidget(m_radiusInput, 6, 6, 0, 2);
- KSeparator *line = new KSeparator (Horizontal, gboxSettings);
+ KSeparator *line = new KSeparator(Qt::Horizontal, gboxSettings);
gridSettings->addMultiCellWidget(line, 7, 7, 0, 2);
// -------------------------------------------------------------
- QLabel *label4 = new QLabel(i18n("Brightness:"), gboxSettings);
+ TQLabel *label4 = new TQLabel(i18n("Brightness:"), gboxSettings);
m_brightnessInput = new KIntNumInput(gboxSettings);
m_brightnessInput->setRange(0, 100, 1, true);
- QWhatsThis::add( m_brightnessInput, i18n("<p>Set here the brightness re-adjustment of the target image."));
+ TQWhatsThis::add( m_brightnessInput, i18n("<p>Set here the brightness re-adjustment of the target image."));
gridSettings->addMultiCellWidget(label4, 8, 8, 0, 2);
gridSettings->addMultiCellWidget(m_brightnessInput, 9, 9, 0, 2);
// -------------------------------------------------------------
- QLabel *label5 = new QLabel(i18n("Contrast:"), gboxSettings);
+ TQLabel *label5 = new TQLabel(i18n("Contrast:"), gboxSettings);
m_contrastInput = new KIntNumInput(gboxSettings);
m_contrastInput->setRange(0, 100, 1, true);
- QWhatsThis::add( m_contrastInput, i18n("<p>Set here the contrast re-adjustment of the target image."));
+ TQWhatsThis::add( m_contrastInput, i18n("<p>Set here the contrast re-adjustment of the target image."));
gridSettings->addMultiCellWidget(label5, 10, 10, 0, 2);
gridSettings->addMultiCellWidget(m_contrastInput, 11, 11, 0, 2);
// -------------------------------------------------------------
- QLabel *label6 = new QLabel(i18n("Gamma:"), gboxSettings);
+ TQLabel *label6 = new TQLabel(i18n("Gamma:"), gboxSettings);
m_gammaInput = new KDoubleNumInput(gboxSettings);
m_gammaInput->setPrecision(2);
m_gammaInput->setRange(0.1, 3.0, 0.01, true);
m_gammaInput->setValue(1.0);
- QWhatsThis::add( m_gammaInput, i18n("<p>Set here the gamma re-adjustment of the target image."));
+ TQWhatsThis::add( m_gammaInput, i18n("<p>Set here the gamma re-adjustment of the target image."));
gridSettings->addMultiCellWidget(label6, 12, 12, 0, 2);
gridSettings->addMultiCellWidget(m_gammaInput, 13, 13, 0, 2);
@@ -176,23 +176,23 @@ ImageEffect_AntiVignetting::ImageEffect_AntiVignetting(QWidget* parent)
// -------------------------------------------------------------
- connect(m_densityInput, SIGNAL(valueChanged (double)),
- this, SLOT(slotTimer()));
+ connect(m_densityInput, TQT_SIGNAL(valueChanged (double)),
+ this, TQT_SLOT(slotTimer()));
- connect(m_powerInput, SIGNAL(valueChanged (double)),
- this, SLOT(slotTimer()));
+ connect(m_powerInput, TQT_SIGNAL(valueChanged (double)),
+ this, TQT_SLOT(slotTimer()));
- connect(m_radiusInput, SIGNAL(valueChanged (double)),
- this, SLOT(slotTimer()));
+ connect(m_radiusInput, TQT_SIGNAL(valueChanged (double)),
+ this, TQT_SLOT(slotTimer()));
- connect(m_brightnessInput, SIGNAL(valueChanged (int)),
- this, SLOT(slotTimer()));
+ connect(m_brightnessInput, TQT_SIGNAL(valueChanged (int)),
+ this, TQT_SLOT(slotTimer()));
- connect(m_contrastInput, SIGNAL(valueChanged (int)),
- this, SLOT(slotTimer()));
+ connect(m_contrastInput, TQT_SIGNAL(valueChanged (int)),
+ this, TQT_SLOT(slotTimer()));
- connect(m_gammaInput, SIGNAL(valueChanged (double)),
- this, SLOT(slotTimer()));
+ connect(m_gammaInput, TQT_SIGNAL(valueChanged (double)),
+ this, TQT_SLOT(slotTimer()));
}
ImageEffect_AntiVignetting::~ImageEffect_AntiVignetting()
@@ -292,19 +292,19 @@ void ImageEffect_AntiVignetting::prepareEffect()
uchar *data = iface->getOriginalImage();
int orgWidth = iface->originalWidth();
int orgHeight = iface->originalHeight();
- QSize ps(orgWidth, orgHeight);
- ps.scale( QSize(120, 120), QSize::ScaleMin );
+ TQSize ps(orgWidth, orgHeight);
+ ps.scale( TQSize(120, 120), TQSize::ScaleMin );
- // Calc mask preview.
+ // Calc tqmask preview.
Digikam::DImg preview(ps.width(), ps.height(), false);
memset(preview.bits(), 255, preview.numBytes());
- AntiVignetting maskPreview(&preview, 0L, d, p, r, 0, 0, false);
- QPixmap pix = maskPreview.getTargetImage().convertToPixmap();
- QPainter pt(&pix);
- pt.setPen( QPen(Qt::black, 1) );
+ AntiVignetting tqmaskPreview(&preview, 0L, d, p, r, 0, 0, false);
+ TQPixmap pix = tqmaskPreview.getTargetImage().convertToPixmap();
+ TQPainter pt(&pix);
+ pt.setPen( TQPen(TQt::black, 1) );
pt.drawRect( 0, 0, pix.width(), pix.height() );
pt.end();
- m_maskPreviewLabel->setPixmap( pix );
+ m_tqmaskPreviewLabel->setPixmap( pix );
Digikam::DImg orgImage(orgWidth, orgHeight, iface->originalSixteenBit(),
iface->originalHasAlpha(), data);